@@ -1,5 +1,5 @@
 package App::JobLog::Log::Note;
-$App::JobLog::Log::Note::VERSION = '1.034';
+$App::JobLog::Log::Note::VERSION = '1.035';
 # ABSTRACT: timestamped annotation in log
 
 
@@ -111,11 +111,11 @@ App::JobLog::Log::Note - timestamped annotation in log
 
 =head1 VERSION
 
-version 1.034
+version 1.035
 
 =head1 DESCRIPTION
 
-B<App::JobLog::Log::Time> fill this out.
+A wrapper for a log line that represents a timestamped and optionally tagged note.
 
 =head1 METHODS
 
